@@ -1,7 +1,7 @@
 package Parallel::ForkManager;
 our $AUTHORITY = 'cpan:DLUX';
 # ABSTRACT:  A simple parallel processing fork manager
-$Parallel::ForkManager::VERSION = '1.18';
+$Parallel::ForkManager::VERSION = '1.19';
 use POSIX ":sys_wait_h";
 use Storable qw(store retrieve);
 use File::Spec;
@@ -64,6 +64,17 @@ sub start {
   }
 }
 
+sub start_child {
+    my $self = shift;
+    my $sub = pop;
+    my $identification = shift;
+
+    $self->start( $identification ) # in the parent
+            # ... or the child
+        or $self->finish( 0, $sub->() );
+}
+
+
 sub finish {
   my ($s, $x, $r)=@_;
 
@@ -289,7 +300,7 @@ Parallel::ForkManager - A simple parallel processing fork manager
 
 =head1 VERSION
 
-version 1.18
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -390,12 +401,17 @@ An optional $process_identifier can be provided to this method... It is used by
 the "run_on_finish" callback (see CALLBACKS) for identifying the finished
 process.
 
+=item start_child [ $process_identifier, ] \&callback
+
+Like C<start>, but will run the C<&callback> as the child. If the callback returns anything,
+it'll be passed as the data to transmit back to the parent process via C<finish()>.
+
 =item finish [ $exit_code [, $data_structure_reference] ]
 
 Closes the child process by exiting and accepts an optional exit code
 (default exit code is 0) which can be retrieved in the parent via callback.
 If the second optional parameter is provided, the child attempts to send
-it's contents back to the parent. If you use the program in debug mode
+its contents back to the parent. If you use the program in debug mode
 ($processes == 0), this method just calls the callback.
 
 If the $data_structure_reference is provided, then it is serialized and
@@ -599,7 +615,7 @@ data structure from a method call. That is not what actually occurs. The
 data structure referenced in a given child process is serialized and
 written out to a file by L<Storable>. The file is subsequently read back
 into memory and a new data structure belonging to the parent process is
-created. Please consider the performance penality it can imply, so try to
+created. Please consider the performance penalty it can imply, so try to
 keep the returned structure small.
 
 =head1 EXAMPLES
@@ -695,7 +711,7 @@ In this simple example, each child sends back a string reference.
         my $string = ${$data_structure_reference};  # child passed a string reference
         print "$string\n";
       }
-      else {  # problems occuring during storage or retrieval will throw a warning
+      else {  # problems occurring during storage or retrieval will throw a warning
         print qq|No message received from child process $pid!\n|;
       }
     }
@@ -802,6 +818,29 @@ process whatever is retrieved.
 
 =for example end
 
+=head1 SECURITY
+
+Parallel::ForkManager uses temporary files when 
+a child process returns information to its parent process. The filenames are
+based on the process of the parent and child processes, so they are 
+fairly easy to guess. So if security is a concern in your environment, make sure
+the directory used by Parallel::ForkManager is restricted to the current user
+only (the default behavior is to create a directory,
+via L<File::Temp>'s C<tempdir>, which does that).
+
+=head1 TROUBLESHOOTING
+
+=head2 PerlIO::gzip and Parallel::ForkManager do not play nice together
+
+If you are using L<PerlIO::gzip> in your child processes, you may end up with 
+garbled files. This is not really P::FM's fault, but rather a problem between
+L<PerlIO::gzip> and C<fork()> (see L<https://rt.cpan.org/Public/Bug/Display.html?id=114557>).
+
+Fortunately, it seems there is an easy way to fix the problem by
+adding the "unix" layer? I.e.,
+
+    open(IN, '<:unix:gzip', ...
+
 =head1 BUGS AND LIMITATIONS
 
 Do not use Parallel::ForkManager in an environment, where other child
